@@ -10,7 +10,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Exporter qw(import);
 our @EXPORT = qw(
@@ -27,6 +27,7 @@ use File::Basename;
 use File::Path 'make_path';
 use File::Copy::Recursive qw/fmove rcopy/;
 use Filesys::DiskUsage qw/du/;
+use File::Which;
 use Cwd 'abs_path';
 
 use Data::Roundtrip qw/perl2dump no-unicode-escape-permanently/;
@@ -979,9 +980,31 @@ sub log {
 # checks if LaTeX::Driver has found the specifed executable.
 # The executable can be something like: latex, pdflatex, xelatex etc.
 # as well as dvips etc.
-# returns the path to the executable if found
+# returns the FULL path to the executable if found
 # or undef if not found or errors (e.g. failed to instantiate LaTeX::Driver)
 sub latex_driver_executable {
+	my $program_name = $_[0];
+	my $pa;
+	if( defined $program_name ){
+		$pa = LaTeX::Driver->program_path($program_name);
+		return undef unless $pa;
+		# this returns undef if not found or not executable (even if via a link)
+		return File::Which::which($pa)
+	}
+	# just iterate over all program names and check them
+	my (%ret, $pk);
+	for $pk (keys %LaTeX::Driver::program_path){
+		if( defined($pa=latex_driver_executable($pk)) ){
+			$ret{$pk} = $pa
+		}
+	}
+	return \%ret;
+}
+
+# to be removed
+sub latex_driver_executable_old {
+	# NOTE you can check program names without LaTeX::Driver object
+	# like this: LaTeX::Driver->program_name('xelatex')
 	my ($program_name) = @_;
 	my $parent = ( caller(1) )[3] || "N/A";
 	my $whoami = ( caller(0) )[3];
@@ -990,7 +1013,13 @@ sub latex_driver_executable {
 	if( ! defined($drivobj) ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : error, failed to instantiate LaTeX::Driver: $@"; return undef }
 	close $fh; unlink $tmpfil;
 	if( defined $program_name ){
-		if( exists($drivobj->{_program_path}->{$program_name}) && defined($drivobj->{_program_path}->{$program_name}) ){
+		if( exists($drivobj->{_program_path}->{$program_name})
+		 && defined($drivobj->{_program_path}->{$program_name})
+		# LaTeX::Driver seems to return 'xelatex' (note: no path)
+		# even if xelatex is not on the system,
+		# so add this check too:
+		 && (-x $drivobj->{_program_path}->{$program_name})
+		){
 			return $drivobj->{_program_path}->{$program_name}
 		}
 		return undef # not found
@@ -1094,7 +1123,7 @@ LaTeX::Easy::Templates - Easily format content into PDF/PS/DVI with LaTeX templa
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -1241,6 +1270,14 @@ from open source, publicly available, superbly styled "I<themes>".
 In this way you can nicely and easily typesed your data
 into a PDF.
 
+=head1 EXPORT
+
+=over 2
+
+=item * L</latex_driver_executable($program_name)>
+
+=back
+
 =head1 METHODS
 
 =head2 C<new()>
@@ -1657,15 +1694,24 @@ This is an exported sub (and not a method)
 
 It enquires L<LaTeX::Driver> for what is the fullpath to the
 program named C<$program_name>. The program can be C<latex>, C<dvips>,
-C<makeindex>, C<pdflatex> etc. If the program is not found it returns C<undef>.
+C<makeindex>, C<pdflatex> etc.
+If the program is not found or if it is not an executable
+(for the current user), it returns C<undef>.
+If it is found and it is executable (for the current user),
+its fullpath is returned.
 
-The parameter is optional, if it is omitted a hash(ref) with all known
-paths is returned.
+The parameter C<$program_name> is optional,
+if it is omitted, it returns a hash(ref) with all known
+programs (the keys)
+and their full paths (the values).
 
-Note that L<LaTeX::Driver>'s paths are detected during its installation.
-Paths can be set during running L</format()> by passing it
-B<latex-E<gt>latex-driver-parameters-E<gt>paths> (a hashref mapping program names
-to their paths).
+Note that L<LaTeX::Driver>'s paths are detected during its installation
+(according to its documentation).
+
+Program full paths can be set during running L</format()> by passing it
+the parameter
+B<latex-E<gt>latex-driver-parameters-E<gt>paths>
+(a hashref mapping program names to their paths).
 
 =head2 C<processors()>
 
